@@ -11,15 +11,15 @@ test progress.
 The following example demonstrates how to use this framework::
 
     import touca
-    from code_under_test import parse_profile, calculate_gpa
+    from code_under_test import find_student, calculate_gpa
 
     @touca.Workflow
     def test_students(testcase: str):
-        student = parse_profile(testcase)
-        touca.add_assertion("username", student.username)
-        touca.add_result("fullname", student.fullname)
-        touca.add_result("birth_date", student.dob)
-        touca.add_result("gpa", calculate_gpa(student.courses))
+        student = find_student(testcase)
+        touca.assume("username", student.username)
+        touca.check("fullname", student.fullname)
+        touca.check("birth_date", student.dob)
+        touca.check("gpa", calculate_gpa(student.courses))
 
     if __name__ == "__main__":
         touca.run()
@@ -241,11 +241,11 @@ class Workflow:
 
         @touca.Workflow
         def test_students(testcase: str):
-            student = parse_profile(testcase)
-            touca.add_assertion("username", student.username)
-            touca.add_result("fullname", student.fullname)
-            touca.add_result("birth_date", student.dob)
-            touca.add_result("gpa", calculate_gpa(student.courses))
+            student = find_student(testcase)
+            touca.assume("username", student.username)
+            touca.check("fullname", student.fullname)
+            touca.check("birth_date", student.dob)
+            touca.check("gpa", calculate_gpa(student.courses))
     """
 
     def __init__(self, func):
